import { Server } from 'socket.io'
import { TSocket } from '../../../utilities/Types'
import path from 'path'
import fs from 'fs/promises'
import spriteRepository from '../../../repositories/SpriteRepository'

type Payload = {
  id: string
}

type Response = string[]

/**
 * Handle game master sprite update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:sprite:action:images', async (data: Payload, callback: (response: Response) => void) => {
    if (socket.character?.role !== 'gm') {
      return
    }

    try {
      const sprite = await spriteRepository.getById(data.id)
      if (!sprite) {
        console.log(`---Sprite not found.`)
        return [];
      }

      const public_folder = path.join(process.cwd(), 'public', 'sprites')
      const sprite_folder = path.join(public_folder, sprite.id)

      const spriteActions = await fs.readdir(sprite_folder)
      const urls = spriteActions.map((action: string) => {
        return path.join(sprite_folder, action)
      })

      callback(urls)
    } catch (error) {
      console.error(error)
      callback([])
    }
  })
}
